[Python-checkins] cpython: Issue #11886: Fix also test_time for the non-DST timezone name (EST/AEST)

victor.stinner python-checkins at python.org
Sat Dec 10 14:37:57 CET 2011


http://hg.python.org/cpython/rev/e37a7dc8944e
changeset:   73921:e37a7dc8944e
user:        Victor Stinner <victor.stinner at haypocalc.com>
date:        Sat Dec 10 14:37:53 2011 +0100
summary:
  Issue #11886: Fix also test_time for the non-DST timezone name (EST/AEST)

files:
  Lib/test/test_time.py |  10 ++++++----
  1 files changed, 6 insertions(+), 4 deletions(-)


diff --git a/Lib/test/test_time.py b/Lib/test/test_time.py
--- a/Lib/test/test_time.py
+++ b/Lib/test/test_time.py
@@ -252,11 +252,13 @@
             self.assertNotEqual(time.gmtime(xmas2002), time.localtime(xmas2002))
 
             # Issue #11886: Australian Eastern Standard Time (UTC+10) is called
             # "EST" (as Eastern Standard Time, UTC-5) instead of "AEST" on some
             # operating systems (e.g. FreeBSD), which is wrong. See for example
             # this bug: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=93810
             self.assertIn(time.tzname[0], ('AEST' 'EST'), time.tzname[0])
-            self.assertTrue(time.tzname[1] == 'AEDT', str(time.tzname[1]))
+            self.assertTrue(time.tzname[1] in ('AEDT', 'EDT'), str(time.tzname[1]))
             self.assertEqual(len(time.tzname), 2)
             self.assertEqual(time.daylight, 1)
             self.assertEqual(time.timezone, -36000)
@@ -252,11 +252,13 @@
 
             # Issue #11886: Australian Eastern Standard Time (UTC+10) is called
-            # "EST" (as Eastern Standard Time, UTC-5) instead of "AEST" on some
-            # operating systems (e.g. FreeBSD), which is wrong. See for example
-            # this bug: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=93810
+            # "EST" (as Eastern Standard Time, UTC-5) instead of "AEST"
+            # (non-DST timezone), and "EDT" instead of "AEDT" (DST timezone),
+            # on some operating systems (e.g. FreeBSD), which is wrong. See for
+            # example this bug:
+            # http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=93810
             self.assertIn(time.tzname[0], ('AEST' 'EST'), time.tzname[0])

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list